==> agordejo_0.3.1.orig.tar.gz: agordejo-0.3.1/README.md <==

[//]: # (Generated 2022-01-15T19:48:12.408433. Changes belong into template/documentation/readme.template)

#Agordejo
Program version 0.3.1


![Screenshot](https://git.laborejo.org/lss/Agordejo/raw/branch/master/documentation/screenshot.png "Screenshot")



Agordejo (Esperanto: 'place to set things up') is a music production session manager.
It is used to start your programs, remember their (JACK) interconnections and make your life easier
in general.


Agordejo does not re-invent the wheel but instead uses the New-Session-Manager daemon and enhances
it with some tricks of its own, that always remain 100% compatible with the original sessions.


This is a proof of concept version. It aims to show that session management with NSM can be quick
and convenient and make the user feel in control. Some functionality has not yet been
implemented, most prominently anything related to NSM over network. There is always the possibility to
break things when trying out corner cases and hacks.


That said, for single-computer sessions with just one daemon and one GUI at the same time Agordejo
should provide a good user experience.


This README is just a short introduction. Consult the manual (see below) for more information.

# Contact and Information

* Website https://www.laborejo.org
* Bugs and Issues: https://www.laborejo.org/bugs
* Git Repositories for all programs: https://git.laborejo.org
* Documentation and Manual https://www.laborejo.org/documentation/agordejo

# Installation and Starting

## Download

### Release Version
If the latest release is not available through your package manger you can build it yourself:
Download the latest code release on https://www.laborejo.org/downloads and extract it.

### Git Version
It is possible to clone a git repository.

`git clone https://git.laborejo.org/lss/agordejo.git`

## Dependencies
* Glibc
* Python 3.6 (maybe earlier)
* PyQt5 for Python 3
* DejaVu Sans Sarif TTF (Font) (recommended, but not technically necessary)
* nsmd: New Session Manager
* grep

#### Build Dependencies
* Bash
* GCC (development is done on 8.2, but most likely you can use a much earlier version)

### Environment:
* Jack Audio Connection Kit must be running

## Build and Install
    ./configure --prefix=/usr/local
    make
    sudo make install


## Starting

If you installed Agordejo through a package manager or yourself simply use your application launcher
or terminal to start the executable `agordejo`

You can also run Agordejo after extracting the release archive or cloning from git, without make or
installation. If you did so, for additional features please link tools/nsm-data to your executable PATH.

Use the manpage `man agordejo` or run `agordejo --help` (or local variant `./agordejo --help` )
to see available command line parameters.

==> agordejo_0.4.2.orig.tar.gz: agordejo-0.4.2/README.md <==

[//]: # (Generated 2022-10-12T23:49:56.705597. Changes belong into template/documentation/readme.template)

#Agordejo
Program version 0.4.2


![Screenshot](https://git.laborejo.org/lss/Agordejo/raw/branch/master/documentation/screenshot.png "Screenshot")



Agordejo (Esperanto: 'place to set things up') is a music production session manager.
It is used to start your programs, remember their (JACK) interconnections and make your life easier
in general.


You can create a session, or project, add programs to it and then use commands to save, start/stop,
hide/show all programs at once, or individually. At a later date you can then re-open
the session and continue where you left off.


Agordejo does not re-invent the wheel but instead uses the New-Session-Manager daemon and enhances
it with some tricks of its own, that always remain 100% compatible with the original sessions.


This README is just a short introduction. Consult the manual (see below) for more information.

# Contact and Information

* Website https://www.laborejo.org
* Bugs and Issues: https://www.laborejo.org/bugs
* Git Repositories for all programs: https://git.laborejo.org
* Documentation and Manual https://www.laborejo.org/documentation/agordejo

# Installation and Starting

## Download

### Release Version
If the latest release is not available through your package manger you can build it yourself:
Download the latest code release on https://www.laborejo.org/downloads and extract it.

### Git Version
It is possible to clone a git repository.

`git clone https://git.laborejo.org/lss/agordejo.git`

## Dependencies
* Glibc
* Python 3.6 (maybe earlier)
* PyQt5 for Python 3
* DejaVu Sans Sarif TTF (Font) (recommended, but not technically necessary)
* nsmd: New Session Manager
* pyxdg: python-xdg

#### Build Dependencies
* Bash
* GCC (development is done on 8.2, but most likely you can use a much earlier version)

### Environment:
* Jack Audio Connection Kit must be running

## Build and Install
    ./configure --prefix=/usr/local
    make
    sudo make install


## Starting

If you installed Agordejo through a package manager or yourself simply use your application launcher
or terminal to start the executable `agordejo`

You can also run Agordejo after extracting the release archive or cloning from git, without make or
installation. If you did so, for additional features please link tools/nsm-data to your executable PATH.

Use the manpage `man agordejo` or run `agordejo --help` (or local variant `./agordejo --help` )
to see available command line parameters.
